# TurtleDov

![GitHub](https://img.shields.io/github/license/HirushaPramuditha/turtledov)

Learn Python the creative way

## Installation

To install TurtleDov, Run this command on terminal

```
$ pip install turtledov
```

## How to use

```python
from turtledov import *
```

`*` for import all fuctions from turtleDov

### Example

Let's draw a square using **turtledov**

```python
from turtledov import *

start()
moveForward(100)
turnRight(90)
moveForward(100)
turnRight(90)
moveForward(100)
turnRight(90)
moveForward(100)
end()
```

You should use `start()` at the start and `end()` at the end

You can see a full list of funtions [here](https://gist.github.com/HirushaPramuditha/5a63ff7b4b0c767ec95190f04dd73340)
